@@ -100,17 +100,6 @@ test_that('missing data', {
   expect_equal(f_pred, exp_f_pred)
 })
 
-# ------------------------------------------------------------------------------
-
-test_that('loaded model data', {
-  expect_error(
-    discrim:::make_discrim_flexible(),
-    "Model `discrim_flexible` already exists"
-  )
-  expect_true(nrow(parsnip:::get_from_env("discrim_flexible"))  == 1)
-})
-
-
 # ------------------------------------------------------------------------------
 
 test_that('printing', {
